@@ -13,7 +13,7 @@ import httpx
 import yarl
 
 
-__version__ = "0.25.0"
+__version__ = "0.25.2"
 __project__ = "aioauth-client"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -150,7 +150,7 @@ class Client(object, metaclass=ClientRegistry):
         transport = self.transport or httpx.AsyncClient()
         async with transport as client:
             response = await client.request(method, url, **options)
-            self.logger.warning("Request %s: %s %r", method, url, options)
+            self.logger.debug("Request %s: %s %r", method, url, options)
             if 'json' in response.headers.get('CONTENT-TYPE'):
                 return response.json()
 
